@@ -21,8 +21,7 @@ import {
   RadioButtonGroup,
   TimePicker
 } from 'carbon-components-react'
-import { getSourcePath, removeVs } from '../../TemplateEditor/utils/utils'
-import Tooltip from '../../TemplateEditor/components/Tooltip'
+import { Tooltip, getSourcePath, removeVs } from 'temptifly'
 import msgs from '../../../../nls/platform.properties'
 import _ from 'lodash'
 
@@ -116,6 +115,7 @@ export class TimeWindow extends React.Component {
 
           <div className="timeWindow-container">
             <RadioButtonGroup
+              key={`mode${mode}`}
               className="timeWindow-mode-container"
               name={`timeWindow-mode-container-${controlId}`}
               defaultSelected={mode ? `"${mode}"` : ''}
@@ -474,7 +474,7 @@ export class TimeWindow extends React.Component {
         ) {
           control.active.timezone = timezoneCache.tz
         }
-        control.active.mode = event.target.value
+        control.active.mode = (event.target.value || '').replace(/"/g, '')
       } else {
         switch (targetName) {
         case 'days-selector':
