@@ -38,7 +38,7 @@ Cypress.Cookies.defaults({
 
 before(() => {
   // Use kubeadmin user to install ansible operator
-  cy.ocLogin("kubeadmin");
+  cy.ocLogin(Cypress.env("OC_CLUSTER_USER"));
   cy.installAnsibleOperator();
   if (Cypress.config().baseUrl.includes("localhost")) {
     cy.ocLogin("cluster-manager-admin");
